@@ -2,7 +2,7 @@
 #
 # barriosqdata.py - barrioSquare data access layer
 # 
-# barrioSquare v0.2.4
+# barrioSquare v0.2.5
 # Copyright(c) 2010 Chili Technologies LLC
 # http://www.chilitechno.com/fster
 #
@@ -32,7 +32,7 @@
 # ============================================================================
 # Name        : barriodata.py
 # Author      : Chris J. Burris - chris@chilitechno.com
-# Version     : 0.2.4
+# Version     : 0.2.5
 # Description : barrioSquare
 # ============================================================================
 
@@ -232,25 +232,59 @@ class DataManager(QtCore.QObject):
 					returnValue = (True, result)
 			del query
 		return returnValue
+	
+	def doQueryOnMainThread(self,queryString):
+		result = False
+		if self.db.isOpen():
+			# print queryString
+			query = QtSql.QSqlQuery(self.db)
+			result = query.exec_(queryString)
+			del query			
+		return result	
 
-	def doSelectQueryOnMainThread(self,queryString,columnList):
+	def doSelectQueryOnMainThread(self,queryString,columnList, connectionName = None, dbFilePath = None):
 		result = { 'RecordCount': 0}
 		result['Records'] = []
 		columns = columnList.split(',')
 		recordCount = 0
-		if self.db.isOpen():
-			# print queryString
-			query = QtSql.QSqlQuery(self.db)
-			if query.exec_(queryString):
-				while query.next():
-					idx = 0
-					row = { }
-					recordCount = recordCount + 1
-					for column in columns:
-						row[column] = query.value(idx)
-						idx = idx + 1
-					result['Records'].append(row)
-			del query
+		if dbFilePath == None:
+			if self.db.isOpen():
+				# print queryString
+				query = QtSql.QSqlQuery(self.db)
+				if query.exec_(queryString):
+					while query.next():
+						idx = 0
+						row = { }
+						recordCount = recordCount + 1
+						for column in columns:
+							row[column] = query.value(idx)
+							idx = idx + 1
+						result['Records'].append(row)
+				del query
+			else:
+				recordCount = -1
+		else:
+			print 'doSelectQueryOnMainThread: %s' % queryString
+			tempdb = QtSql.QSqlDatabase.addDatabase("QSQLITE",connectionName)
+			tempdb.setDatabaseName(dbFilePath)
+			if tempdb.open():
+				query = QtSql.QSqlQuery(tempdb)
+				if query.exec_(queryString):
+					while query.next():
+						idx = 0
+						row = { }
+						recordCount = recordCount + 1
+						for column in columns:
+							row[column] = query.value(idx)
+							idx = idx + 1
+						result['Records'].append(row)
+				del query		
+				tempdb.close()
+				del tempdb
+			else:
+				print 'doSelectQueryOnMainThread: db not open!'	
+				recordCount = -1		
+						
 		result['RecordCount'] = recordCount		
 		return result
 
